@@ -12,9 +12,9 @@ use DBIx::Custom;
 #------------------------------------------------------------------------------
 with 'Firewall::DBI::Role';
 
-has option => ( is => 'ro', isa => 'Undef | HashRef[Str]', default => undef, );
+has option => (is => 'ro', isa => 'Undef | HashRef[Str]', default => undef,);
 
-has '+dbi' => ( isa => 'DBIx::Custom', handles => qr/^(?:select|update|insert|delete|execute|user).*/, );
+has '+dbi' => (isa => 'DBIx::Custom', handles => qr/^(?:select|update|insert|delete|execute|user).*/,);
 
 for my $func (qw( execute delete update insert batchExecute )) {
   around $func => sub {
@@ -27,8 +27,8 @@ for my $func (qw( execute delete update insert batchExecute )) {
       $self->dbi->dbh->commit;
     };
 
-    if ( !!$@ ) {
-      if ( $self->dbi->dbh->rollback ) {
+    if (!!$@) {
+      if ($self->dbi->dbh->rollback) {
         confess "ERROR: $@";
       }
       else {
@@ -44,9 +44,9 @@ for my $func (qw( execute delete update insert batchExecute )) {
 around BUILDARGS => sub {
   my $orig  = shift;
   my $class = shift;
-  my %param = ( @_ > 0 and ref( $_[0] ) eq 'HASH' ) ? %{$_[0]} : @_;
+  my %param = (@_ > 0 and ref($_[0]) eq 'HASH') ? %{$_[0]} : @_;
 
-  if ( not defined $param{dsn} and defined $param{host} and defined $param{port} and defined $param{sid} ) {
+  if (not defined $param{dsn} and defined $param{host} and defined $param{port} and defined $param{sid}) {
     $param{dsn} = "dbi:Oracle:host=$param{host};sid=$param{sid};port=$param{port}";
   }
 
@@ -55,8 +55,7 @@ around BUILDARGS => sub {
 
 sub clone {
   my $self = shift;
-  return __PACKAGE__->new( dsn => $self->dsn, user => $self->user, password => $self->password,
-    option => $self->option );
+  return __PACKAGE__->new(dsn => $self->dsn, user => $self->user, password => $self->password, option => $self->option);
 }
 
 sub batchExecute {
@@ -67,21 +66,21 @@ sub batchExecute {
 sub _rawExecute {
 
   # 比multipleInsert略快，适合大批量或语句较复杂的操作
-  my ( $self, $paramRef, $sqlString ) = @_;
+  my ($self, $paramRef, $sqlString) = @_;
   my $num = 0;
   my $sth = $self->dbi->dbh->prepare($sqlString);
-  for my $param ( @{$paramRef} ) {
-    $sth->execute( @{$param} );
+  for my $param (@{$paramRef}) {
+    $sth->execute(@{$param});
     $self->dbi->dbh->commit if ++$num % 5000 == 0;
   }
 }
 
 sub _buildDbi {
   my $self  = shift;
-  my %param = ( dsn => $self->dsn, user => $self->user, password => $self->password );
+  my %param = (dsn => $self->dsn, user => $self->user, password => $self->password);
   $param{option} = $self->option // {AutoCommit => 0, RaiseError => 1, PrintError => 0};
 
-  if ( defined $ENV{LANG} ) {
+  if (defined $ENV{LANG}) {
     $ENV{NLS_CURRENCY}      = '*';
     $ENV{NLS_DUAL_CURRENCY} = '*';
   }
