@@ -8,5 +8,5 @@ use DBI;
 
 my @driver_names = DBI->available_drivers;
 my %drivers      = DBI->installed_drivers;
-say dumper \@driver_names;
-say dumper \%drivers;
+print dumper \@driver_names;
+print dumper \%drivers;
